package com.gic.cloud.data.hook.service.deal.queryfilter;

import com.gic.api.base.commons.Page;
import com.gic.cloud.data.hook.api.dto.FilterQueryDataDTO;
import com.gic.cloud.data.hook.api.enums.QueryFilterCodeEnum;
import com.gic.cloud.data.hook.service.deal.BaseQueryFilter;
import com.gic.cloud.data.hook.service.deal.QueryFilterContext;
import com.gic.cloud.data.hook.service.entity.QueryFilterInfo;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.api.dto.PowerStoreGroupDTO;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StoreSearchDTO;
import com.gic.enterprise.api.service.StoreGroupService;
import com.gic.enterprise.api.service.StoreService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Service
public class StoreGroupNameQueryFilter implements BaseQueryFilter {

    @Autowired
    private StoreGroupService storeGroupService;

    @Override
    public boolean checkFilter(QueryFilterContext context) {
        QueryFilterInfo queryFilterInfo = context.getQueryFilterInfo();
        if (null == queryFilterInfo||queryFilterInfo.getFilterCode()==null) {
            return false;
        }
        return queryFilterInfo.getFilterCode().equals(QueryFilterCodeEnum.STORE_GROUP_NAME.getCode());
    }

    @Override
    public Page<FilterQueryDataDTO> pageQueryData(QueryFilterContext context) {

        List<PowerStoreGroupDTO> storeGroupList = storeGroupService.getStoreGroupList(context.getEnterpriseId());
        Map<String, PowerStoreGroupDTO> storeGroupMap = storeGroupList.stream().collect(Collectors.toMap(mid -> mid.getStoreGroupId(), mid -> mid));

        Set<FilterQueryDataDTO> retList = storeGroupList.stream().map(mid -> {
            String storeGroupChainName = getStoreGroupChainName(storeGroupMap, mid);
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(storeGroupChainName);
            filterQueryDataDTO.setItemValue(storeGroupChainName);
            filterQueryDataDTO.setItemId(storeGroupChainName);
            return filterQueryDataDTO;
        }).collect(Collectors.toSet());

        Page<FilterQueryDataDTO> page = new Page<>();
        page.setTotalCount(retList.size());
        page.setPageSize(retList.size());
        page.setCurrentPage(1);
        page.setResult(new ArrayList<>(retList));
        return page;

    }

    /**
     * 组装链路名称
     * @param storeGroupDTOMap
     * @param current
     * @return
     */
    private String getStoreGroupChainName(Map<String, PowerStoreGroupDTO> storeGroupDTOMap,PowerStoreGroupDTO current) {
        if (current == null) {
            return null;
        }
        String ret=current.getStoreGroupName();
        String parentGroupId = current.getParentGroupId();
        if (parentGroupId.equals("0")) {
            return ret;
        }
        PowerStoreGroupDTO powerStoreGroupDTO = storeGroupDTOMap.get(parentGroupId);
        if (powerStoreGroupDTO== null) {
            return ret;
        }
        String subChain = getStoreGroupChainName(storeGroupDTOMap, powerStoreGroupDTO);
        return subChain+"/"+ret;

    }

    @Override
    public List<FilterQueryDataDTO> listBackByItems(QueryFilterContext context) {
        List<String> items = context.getItems();
        return items.stream().map(mid->{
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(mid);
            filterQueryDataDTO.setItemValue(mid);
            filterQueryDataDTO.setItemId(mid);
            return filterQueryDataDTO;
        }).collect(Collectors.toList());
    }
}


